
## 0.1.1 (2023-02-14)

### chore

- increment patch version as version 1.0.0 has been burn by pypi.org

## 0.1.0 (2023-02-14)

### fix

- missing cafram submodule

## 0.1.0a6 (2023-02-14)

### feat

- add official favicon

### fix

- missing files in schema doc generator

### docs

- Update dev parts

### chore

- update json-schema-for-humans dep

### ci

- add script to generate favicon
- fix publish idempotency
- add script to generate favicon
- fix missing rich dep

## 0.1.0a5 (2023-02-14)

### fix

- missing python dependencies

## 0.1.0a4 (2023-02-13)

### ci

- fix missing deps

## 0.1.0a3 (2023-02-13)

### docs

- update developper docs

### ci

- fix environment vars
- add bumping sanity check

## 0.1.0a2 (2023-02-13)

### fix

- disable changelog file output
- simple bugfix2
- simple bugfix1

### ci

- fix scripts
- clean uneeded tasks
- update scripts

## 0.1.0a1 (2023-02-13)

### docs

- update devel docs

## 0.1.0a0 (2023-02-13)

### fix

- version handling
- version handling
- bad cafram dependency
- typo in .envrc

### docs

- update cz config
- remove unecessary html tags

### chore

- paasify now retrieve its version from python pkg
- cleanup python deps

### ci

- fix changelog regex format
- fix changelog regex format
- fix changelog regex format
- change again changelog format
- test versionning

## v0.1.0rc7 (2023-02-10)

### Fix

- bad version in app

## v0.1.0rc6 (2023-02-10)

### Fix

- cz version patch config

## v0.1.0rc5 (2023-02-10)

### Fix

- cz version patch config

## v0.1.0rc4 (2023-02-10)

### Fix

- fake bugfix

## v0.1.0rc3 (2023-02-10)

### Fix

- fake bugfix

## v0.1.0rc2 (2023-02-10)

### Fix

- fake bugfix
- fake bugfix

## v0.1.0rc1 (2023-02-10)

## v0.1.0rc0 (2023-02-10)

### Feat

- new code for rc0
- Homepage integration via jsonnet tag
- Flame integration via jsonnet tag

### Fix

- config error in pre-commit config
- semver deprecation warnings
- test_cli missing check on docker daemon presence
- typo in main logo
- and update jsonnet filters
- missing directory creation for volumes
- traefik tag bug about domains
- taskfile missing tokens
- taskfile bugs
- CHANGELOG generation
- taskfile bugs
- taskfile bugs
- taskfile bugs
- taskfile bugs
- missing dependencies
- python version
- cafram submodule
- commited cafram files
- lint docker related files
- lint examples
- lint test code
- lint paasify code
- missing prefixed command
